@@ -80,6 +80,7 @@
 #define WINLIST_SHOW_WS_SUBMENUS_PROP        "/windowlist-menu/show-submenus"
 #define WINLIST_SHOW_ADD_REMOVE_WORKSPACES_PROP "/windowlist-menu/show-add-remove-workspaces"
 
+#define DESKTOP_ICONS_ON_PRIMARY_PROP        "/desktop-icons/primary"
 #define DESKTOP_ICONS_STYLE_PROP             "/desktop-icons/style"
 #define DESKTOP_ICONS_ICON_SIZE_PROP         "/desktop-icons/icon-size"
 #define DESKTOP_ICONS_FONT_SIZE_PROP         "/desktop-icons/font-size"
@@ -87,6 +88,7 @@
 #define DESKTOP_ICONS_SHOW_TOOLTIP_PROP      "/desktop-icons/show-tooltips"
 #define DESKTOP_ICONS_TOOLTIP_SIZE_PROP      "/desktop-icons/tooltip-size"
 #define DESKTOP_ICONS_SINGLE_CLICK_PROP      "/desktop-icons/single-click"
+#define DESKTOP_ICONS_GRAVITY_PROP           "/desktop-icons/gravity"
 
 typedef struct
 {
@@ -442,9 +444,9 @@ setup_special_icon_list(GtkBuilder *gxml,
         GdkPixbuf *pix = NULL;
 
         if(gtk_icon_theme_has_icon(itheme, icons[i].icon))
-            pix = gtk_icon_theme_load_icon(itheme, icons[i].icon, w, 0, NULL);
+            pix = gtk_icon_theme_load_icon(itheme, icons[i].icon, w, GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
         else
-            pix = gtk_icon_theme_load_icon(itheme, icons[i].icon_fallback, w, 0, NULL);
+            pix = gtk_icon_theme_load_icon(itheme, icons[i].icon_fallback, w, GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
 
         if(i < REMOVABLE_DEVICES) {
             gtk_tree_store_append(ts, &parent_iter, NULL);
@@ -470,6 +472,7 @@ setup_special_icon_list(GtkBuilder *gxml,
     treeview = GTK_WIDGET(gtk_builder_get_object(gxml, "treeview_default_icons"));
     g_object_set_data(G_OBJECT(treeview), "xfconf-channel", channel);
     col = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_spacing(col, 6);
     gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), col);
 
     render = gtk_cell_renderer_toggle_new();
@@ -721,11 +724,7 @@ xfdesktop_settings_update_iconview_frame_name(AppearancePanel *panel,
 
     workspace_name = g_strdup(wnck_workspace_get_name(workspace));
 
-#if 0 /* GTK_CHECK_VERSION (3, 22, 0) */
     if(gdk_display_get_n_monitors(gtk_widget_get_display(panel->chk_apply_to_all)) > 1) {
-#else
-    if(gdk_screen_get_n_monitors(gtk_widget_get_screen(panel->chk_apply_to_all)) > 1) {
-#endif
         if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(panel->chk_apply_to_all))) {
             /* Multi-monitor single workspace */
             if(panel->monitor_name) {
@@ -994,7 +993,7 @@ update_backdrop_cycle_spinbox(AppearancePanel *panel)
     if(gtk_widget_get_sensitive(panel->combo_backdrop_cycle_period)) {
         period = gtk_combo_box_get_active(GTK_COMBO_BOX(panel->combo_backdrop_cycle_period));
         if(period == XFCE_BACKDROP_PERIOD_SECONDS ||
-           period == XFCE_BACKDROP_PERIOD_MINUES  ||
+           period == XFCE_BACKDROP_PERIOD_MINUTES  ||
            period == XFCE_BACKDROP_PERIOD_HOURS)
         {
             sensitive = TRUE;
@@ -1434,7 +1433,7 @@ xfdesktop_settings_background_tab_change_bindings(AppearancePanel *panel,
                                G_OBJECT(panel->combo_backdrop_cycle_period), "active");
     } else {
         /* default is minutes, set that before we bind to it */
-        gtk_combo_box_set_active(GTK_COMBO_BOX(panel->combo_backdrop_cycle_period), XFCE_BACKDROP_PERIOD_MINUES);
+        gtk_combo_box_set_active(GTK_COMBO_BOX(panel->combo_backdrop_cycle_period), XFCE_BACKDROP_PERIOD_MINUTES);
 
         xfconf_g_property_bind(channel, buf, G_TYPE_INT,
                                G_OBJECT(panel->combo_backdrop_cycle_period), "active");
@@ -1483,7 +1482,6 @@ suboptions_set_sensitive(GtkToggleButton *btn,
     gtk_widget_set_sensitive(box, gtk_toggle_button_get_active(btn));
 }
 
-#if 0 /* GTK_CHECK_VERSION (3, 22, 0) */
 static gint
 display_get_monitor_num(GdkDisplay *display, GdkMonitor *monitor)
 {
@@ -1500,7 +1498,6 @@ display_get_monitor_num(GdkDisplay *display, GdkMonitor *monitor)
     g_warning("unable to get the monitor number");
     return 0;
 }
-#endif
 
 static void
 cb_update_background_tab(WnckWindow *wnck_window,
@@ -1512,10 +1509,8 @@ cb_update_background_tab(WnckWindow *wnck_window,
     WnckWorkspace *wnck_workspace = NULL;
     WnckScreen    *wnck_screen = NULL;
     GdkWindow     *window = NULL;
-#if 0 /* GTK_CHECK_VERSION (3, 22, 0) */
     GdkDisplay    *display = NULL;
     GdkMonitor    *monitor = NULL;
-#endif
 
     /* If we haven't found our window return now and wait for that */
     if(panel->wnck_window == NULL)
@@ -1528,13 +1523,9 @@ cb_update_background_tab(WnckWindow *wnck_window,
     workspace_num = xfdesktop_settings_get_active_workspace(panel, wnck_window);
     screen_num = wnck_screen_get_number(wnck_screen);
     window = gtk_widget_get_window(panel->image_iconview);
-#if 0 /* GTK_CHECK_VERSION (3, 22, 0) */
     display = gdk_window_get_display(window);
     monitor = gdk_display_get_monitor_at_window(display, window);
     monitor_num = display_get_monitor_num(display, monitor);
-#else
-    monitor_num = gdk_screen_get_monitor_at_window(gtk_widget_get_screen(panel->image_iconview), window);
-#endif
     monitor_name = xfdesktop_get_monitor_name_from_gtk_widget(panel->image_iconview, monitor_num);
 
     /* Most of the time we won't change monitor, screen, or workspace so try
@@ -1578,17 +1569,12 @@ cb_update_background_tab(WnckWindow *wnck_window,
      */
     gtk_combo_box_text_remove(GTK_COMBO_BOX_TEXT(panel->image_style_combo),
                               XFCE_BACKDROP_IMAGE_SPANNING_SCREENS);
-#if 0 /* GTK_CHECK_VERSION (3, 22, 0) */
+
     if(panel->monitor == 0 && gdk_display_get_n_monitors(gtk_widget_get_display(panel->image_style_combo)) > 1) {
         gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(panel->image_style_combo),
                                        _("Spanning screens"));
     }
-#else
-    if(panel->monitor == 0 && gdk_screen_get_n_monitors(gtk_widget_get_screen(panel->image_iconview)) > 1) {
-        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(panel->image_style_combo),
-                                       _("Spanning screens"));
-    }
-#endif
+
 
     /* connect the new bindings */
     xfdesktop_settings_background_tab_change_bindings(panel,
@@ -1748,6 +1734,36 @@ xfdesktop_settings_setup_image_iconview(AppearancePanel *panel)
                      G_CALLBACK(cb_thumbnail_ready), panel);
 }
 
+static void
+cb_xfdesktop_icon_orientation_changed(GtkComboBox *combo,
+                                      gpointer user_data)
+{
+    const gchar *cmd = "xfdesktop --arrange";
+    /* TRANSLATORS: Please split the message in half with '\n' so the dialog will not be too wide. */
+    const gchar *question = _("Would you like to arrange all existing\n"
+                              "icons according to the selected orientation?");
+    GError *error = NULL;
+
+    GtkWindow *window = GTK_WINDOW (gtk_widget_get_toplevel(GTK_WIDGET(combo)));
+
+    if(!xfce_dialog_confirm(window, "view-sort-ascending", _("Arrange icons"),
+                            NULL, "%s", question))
+    {
+        return;
+    }
+
+    if(!g_spawn_command_line_async(cmd, &error))
+    {
+        gchar *primary = g_strdup_printf(_("Unable to launch \"%s\":"), cmd);
+        xfce_message_dialog(window, _("Launch Error"),
+                            "dialog-error", primary, error->message,
+                            XFCE_BUTTON_TYPE_MIXED, "window-close", _("_Close"),
+                            GTK_RESPONSE_ACCEPT, NULL);
+        g_free(primary);
+        g_clear_error(&error);
+    }
+}
+
 static void
 xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
                                      AppearancePanel *panel)
@@ -1967,7 +1983,7 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
                                                                      "chk_random_backdrop_order"));
 
     /* Pick the first entry so something shows up */
-    gtk_combo_box_set_active(GTK_COMBO_BOX(panel->combo_backdrop_cycle_period), XFCE_BACKDROP_PERIOD_MINUES);
+    gtk_combo_box_set_active(GTK_COMBO_BOX(panel->combo_backdrop_cycle_period), XFCE_BACKDROP_PERIOD_MINUTES);
 
     g_signal_connect(G_OBJECT(panel->backdrop_cycle_chkbox), "toggled",
                     G_CALLBACK(cb_xfdesktop_chk_cycle_backdrop_toggled),
@@ -2030,6 +2046,9 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
                            gtk_builder_get_object(main_gxml, "chk_show_winlist_ws_submenus"),
                            "active");
 
+    w = GTK_WIDGET(gtk_builder_get_object(main_gxml, "primary"));
+    xfconf_g_property_bind(channel, DESKTOP_ICONS_ON_PRIMARY_PROP, G_TYPE_BOOLEAN,
+                          G_OBJECT(w), "active");
     w = GTK_WIDGET(gtk_builder_get_object(main_gxml, "combo_icons"));
 #ifdef ENABLE_FILE_ICONS
     gtk_combo_box_set_active(GTK_COMBO_BOX(w), 2);
@@ -2038,6 +2057,16 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
 #endif
     xfconf_g_property_bind(channel, DESKTOP_ICONS_STYLE_PROP, G_TYPE_INT,
                            G_OBJECT(w), "active");
+
+    /* Orientation combo */
+    w = GTK_WIDGET(gtk_builder_get_object(main_gxml, "combo_orientation"));
+    gtk_combo_box_set_active(GTK_COMBO_BOX(w), 0);
+    xfconf_g_property_bind(channel, DESKTOP_ICONS_GRAVITY_PROP, G_TYPE_INT,
+                           G_OBJECT(w), "active");
+    g_signal_connect(G_OBJECT(w), "changed",
+                     G_CALLBACK(cb_xfdesktop_icon_orientation_changed), NULL);
+
+    /* bindings */
     xfconf_g_property_bind(channel, DESKTOP_ICONS_FONT_SIZE_PROP, G_TYPE_DOUBLE,
                            G_OBJECT(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(spin_font_size))),
                            "value");
