@@ -51,7 +51,7 @@ typedef enum
 struct _XfceDesktop
 {
     GtkWindow window;
-    
+
     /*< private >*/
     XfceDesktopPriv *priv;
 };
@@ -59,13 +59,13 @@ struct _XfceDesktop
 struct _XfceDesktopClass
 {
     GtkWindowClass parent_class;
-    
+
     /*< signals >*/
-    
+
     /* for the app menu/file context menu */
     void (*populate_root_menu)(XfceDesktop *desktop,
                                GtkMenuShell *menu);
-    
+
     /* for the windowlist menu */
     void (*populate_secondary_root_menu)(XfceDesktop *desktop,
                                          GtkMenuShell *menu);
@@ -89,11 +89,17 @@ XfceDesktopIconStyle xfce_desktop_get_icon_style(XfceDesktop *desktop);
 void xfce_desktop_set_icon_size(XfceDesktop *desktop,
                                 guint icon_size);
 
+void xfce_desktop_set_primary(XfceDesktop *desktop,
+                              gboolean primary);
+
 void xfce_desktop_set_use_icon_font_size(XfceDesktop *desktop,
                                          gboolean use_system);
 void xfce_desktop_set_icon_font_size(XfceDesktop *desktop,
                                      guint font_size_points);
 
+void xfce_desktop_set_center_text(XfceDesktop *desktop,
+                                  gboolean center_text);
+
 void xfce_desktop_set_session_logout_func(XfceDesktop *desktop,
                                           SessionLogoutFunc logout_func);
 
